@@ -34,7 +34,7 @@ class FDB;
 
 class DistFDB : public FDBBase {
 
-public: // method
+public:  // method
 
     using FDBBase::stats;
 
@@ -47,7 +47,7 @@ public: // method
 
     ListIterator list(const FDBToolRequest& request, int level) override;
 
-    AxesIterator axesIterator(const FDBToolRequest& request, int level=3) override { NOTIMP; }
+    AxesIterator axesIterator(const FDBToolRequest& request, int level = 3) override { NOTIMP; }
 
     DumpIterator dump(const FDBToolRequest& request, bool simple) override;
 
@@ -59,8 +59,7 @@ public: // method
 
     StatsIterator stats(const FDBToolRequest& request) override;
 
-    ControlIterator control(const FDBToolRequest& request,
-                            ControlAction action,
+    ControlIterator control(const FDBToolRequest& request, ControlAction action,
                             ControlIdentifiers identifiers) override;
 
     MoveIterator move(const FDBToolRequest& request, const eckit::URI& dest) override;
@@ -69,7 +68,7 @@ public: // method
 
     FDBStats stats() const override;
 
-private: // methods
+private:  // methods
 
     void print(std::ostream& s) const override;
 
@@ -85,6 +84,6 @@ private:
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
-#endif // fdb5_api_DistFDB_H
+#endif  // fdb5_api_DistFDB_H
