@@ -47,10 +47,8 @@ namespace fdb5 {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-FDB::FDB(const Config &config) :
-    internal_(FDBFactory::instance().build(config)),
-    dirty_(false),
-    reportStats_(config.getBool("statistics", false)) {
+FDB::FDB(const Config& config) :
+    internal_(FDBFactory::instance().build(config)), dirty_(false), reportStats_(config.getBool("statistics", false)) {
     LibFdb5::instance().constructorCallback()(*internal_);
 }
 
@@ -71,7 +69,7 @@ void FDB::archive(eckit::DataHandle& handle) {
     eckit::message::Message msg;
     eckit::message::Reader reader(handle);
 
-    while ( (msg = reader.next()) ) {
+    while ((msg = reader.next())) {
         archive(msg);
     }
 }
@@ -86,12 +84,12 @@ void FDB::archive(const metkit::mars::MarsRequest& request, eckit::DataHandle& h
 
     metkit::hypercube::HyperCube cube(request);
 
-    while ( (msg = reader.next()) ) {
+    while ((msg = reader.next())) {
         fdb5::Key key = MessageDecoder::messageToKey(msg);
         if (!cube.clear(key.request())) {
             std::stringstream ss;
             ss << "FDB archive - found unexpected message" << std::endl;
-            ss << "  user request:"  << std::endl << "    " << request << std::endl;
+            ss << "  user request:" << std::endl << "    " << request << std::endl;
             ss << "  unexpected message:" << std::endl << "    " << key << std::endl;
             LOG_DEBUG_LIB(LibFdb5) << ss.str();
             throw eckit::UserError(ss.str(), Here());
@@ -101,7 +99,7 @@ void FDB::archive(const metkit::mars::MarsRequest& request, eckit::DataHandle& h
     if (cube.countVacant()) {
         std::stringstream ss;
         ss << "FDB archive - missing " << cube.countVacant() << " messages" << std::endl;
-        ss << "  user request:"  << std::endl << "    " << request << std::endl;
+        ss << "  user request:" << std::endl << "    " << request << std::endl;
         ss << "  missing messages:" << std::endl;
         for (auto vacantRequest : cube.vacantRequests()) {
             ss << "    " << vacantRequest << std::endl;
@@ -138,7 +136,12 @@ void FDB::archive(const Key& key, const void* data, size_t length) {
     stats_.addArchive(length, timer);
 }
 
-bool FDB::sorted(const metkit::mars::MarsRequest &request) {
+void FDB::reindex(const Key& key, const FieldLocation& location) {
+    internal_->reindex(key, location);
+    dirty_ = true;
+}
+
+bool FDB::sorted(const metkit::mars::MarsRequest& request) {
 
     bool sorted = false;
 
@@ -156,6 +159,7 @@ bool FDB::sorted(const metkit::mars::MarsRequest &request) {
 
 class ListElementDeduplicator : public metkit::hypercube::Deduplicator<ListElement> {
 public:
+
     bool toReplace(const ListElement& existing, const ListElement& replacement) const override {
         return existing.timestamp() < replacement.timestamp();
     }
@@ -189,7 +193,7 @@ eckit::DataHandle* FDB::read(ListIterator& it, bool sorted) {
         if (it.next(el)) {
             // build the request representing the tensor-product of all retrieved fields
             metkit::mars::MarsRequest cubeRequest = el.combinedKey().request();
-            std::vector<ListElement>  elements {el};
+            std::vector<ListElement> elements{el};
 
             while (it.next(el)) {
                 cubeRequest.merge(el.combinedKey().request());
@@ -199,12 +203,14 @@ eckit::DataHandle* FDB::read(ListIterator& it, bool sorted) {
             // checking all retrieved fields against the hypercube, to remove duplicates
             ListElementDeduplicator deduplicator;
             metkit::hypercube::HyperCubePayloaded<ListElement> cube(cubeRequest, deduplicator);
-            for (const auto& elem : elements) { cube.add(elem.combinedKey().request(), el); }
+            for (const auto& elem : elements) {
+                cube.add(elem.combinedKey().request(), el);
+            }
 
             if (cube.countVacant() > 0) {
                 std::stringstream ss;
                 ss << "No matching data for requests:" << std::endl;
-                for (auto req: cube.vacantRequests()) {
+                for (auto req : cube.vacantRequests()) {
                     ss << "    " << req << std::endl;
                 }
                 eckit::Log::warning() << ss.str() << std::endl;
@@ -251,11 +257,11 @@ WipeIterator FDB::wipe(const FDBToolRequest& request, bool doit, bool porcelain,
     return internal_->wipe(request, doit, porcelain, unsafeWipeAll);
 }
 
-PurgeIterator FDB::purge(const FDBToolRequest &request, bool doit, bool porcelain) {
+PurgeIterator FDB::purge(const FDBToolRequest& request, bool doit, bool porcelain) {
     return internal_->purge(request, doit, porcelain);
 }
 
-StatsIterator FDB::stats(const FDBToolRequest &request) {
+StatsIterator FDB::stats(const FDBToolRequest& request) {
     return internal_->stats(request);
 }
 
@@ -283,7 +289,7 @@ const std::string& FDB::name() const {
     return internal_->name();
 }
 
-const Config &FDB::config() const {
+const Config& FDB::config() const {
     return internal_->config();
 }
 
@@ -344,4 +350,4 @@ void FDB::registerFlushCallback(FlushCallback callback) {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
