@@ -22,22 +22,22 @@
 #include <memory>
 
 #include "eckit/distributed/Transport.h"
-#include "eckit/utils/Regex.h"
 #include "eckit/memory/NonCopyable.h"
+#include "eckit/utils/Regex.h"
 
-#include "fdb5/database/Catalogue.h"
-#include "fdb5/config/Config.h"
 #include "fdb5/api/FDBStats.h"
 #include "fdb5/api/helpers/AxesIterator.h"
-#include "fdb5/api/helpers/ListIterator.h"
+#include "fdb5/api/helpers/Callback.h"
 #include "fdb5/api/helpers/ControlIterator.h"
 #include "fdb5/api/helpers/DumpIterator.h"
-#include "fdb5/api/helpers/WipeIterator.h"
+#include "fdb5/api/helpers/ListIterator.h"
 #include "fdb5/api/helpers/MoveIterator.h"
 #include "fdb5/api/helpers/PurgeIterator.h"
 #include "fdb5/api/helpers/StatsIterator.h"
 #include "fdb5/api/helpers/StatusIterator.h"
-#include "fdb5/api/helpers/Callback.h"
+#include "fdb5/api/helpers/WipeIterator.h"
+#include "fdb5/config/Config.h"
+#include "fdb5/database/Catalogue.h"
 
 namespace eckit::message {
 
@@ -49,7 +49,7 @@ namespace metkit {
 
 class MarsRequest;
 
-} // namespace metkit
+}  // namespace metkit
 
 namespace fdb5 {
 
@@ -62,7 +62,7 @@ class FDBToolRequest;
 
 class FDBBase : private eckit::NonCopyable, public CallbackRegistry {
 
-public: // methods
+public:  // methods
 
     FDBBase(const Config& config, const std::string& name);
     virtual ~FDBBase();
@@ -70,7 +70,9 @@ public: // methods
     // -------------- Primary API functions ----------------------------
 
     virtual void archive(const Key& key, const void* data, size_t length) = 0;
-    
+
+    virtual void reindex(const Key& key, const FieldLocation& location) { NOTIMP; }
+
     virtual void flush() = 0;
 
     virtual ListIterator inspect(const metkit::mars::MarsRequest& request) = 0;
@@ -87,8 +89,7 @@ public: // methods
 
     virtual StatsIterator stats(const FDBToolRequest& request) = 0;
 
-    virtual ControlIterator control(const FDBToolRequest& request,
-                                    ControlAction action,
+    virtual ControlIterator control(const FDBToolRequest& request, ControlAction action,
                                     ControlIdentifiers identifier) = 0;
 
     virtual MoveIterator move(const FDBToolRequest& request, const eckit::URI& dest) = 0;
@@ -112,7 +113,7 @@ public: // methods
 
     bool enabled(const ControlIdentifier& controlIdentifier) const;
 
-private: // methods
+private:  // methods
 
     virtual void print(std::ostream& s) const = 0;
 
@@ -121,7 +122,7 @@ private: // methods
         return s;
     }
 
-protected: // members
+protected:  // members
 
     const std::string name_;
 
@@ -130,7 +131,6 @@ protected: // members
     ControlIdentifiers controlIdentifiers_;
 
     bool disabled_;
-
 };
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -148,43 +148,42 @@ public:
 
 private:
 
-    FDBFactory() {} ///< private constructor only used by singleton
+    FDBFactory() {}  ///< private constructor only used by singleton
 
     eckit::Mutex mutex_;
 
     std::map<std::string, const FDBBuilderBase*> registry_;
-
 };
 
 
 class FDBBuilderBase {
-public: // methods
+public:  // methods
 
     virtual std::unique_ptr<FDBBase> make(const Config& config) const = 0;
 
-protected: // methods
+protected:  // methods
 
     FDBBuilderBase(const std::string& name);
 
     virtual ~FDBBuilderBase();
 
-protected: // members
+protected:  // members
 
     std::string name_;
 };
 
 
-
 template <typename T>
 class FDBBuilder : public FDBBuilderBase {
 
-    static_assert(std::is_base_of<FDBBase, T>::value, "FDB Factorys can only build implementations of the FDB interface");
+    static_assert(std::is_base_of<FDBBase, T>::value,
+                  "FDB Factorys can only build implementations of the FDB interface");
 
-public: // methods
+public:  // methods
 
     FDBBuilder(const std::string& name) : FDBBuilderBase(name) {}
 
-private: // methods
+private:  // methods
 
     std::unique_ptr<FDBBase> make(const Config& config) const override {
         return std::unique_ptr<T>(new T(config, name_));
@@ -193,6 +192,6 @@ private: // methods
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
-#endif // fdb5_api_FDBFactory_H
+#endif  // fdb5_api_FDBFactory_H
