@@ -20,6 +20,7 @@
 #define fdb5_api_LocalFDB_H
 
 #include "fdb5/api/FDBFactory.h"
+#include "fdb5/database/Reindexer.h"
 
 
 namespace fdb5 {
@@ -32,13 +33,15 @@ class FDB;
 
 class LocalFDB : public FDBBase {
 
-public: // methods
+public:  // methods
 
     using FDBBase::FDBBase;
     using FDBBase::stats;
 
     void archive(const Key& key, const void* data, size_t length) override;
 
+    void reindex(const Key& key, const FieldLocation& location) override;
+
     ListIterator inspect(const metkit::mars::MarsRequest& request) override;
 
     ListIterator list(const FDBToolRequest& request, int level) override;
@@ -53,8 +56,7 @@ public: // methods
 
     StatsIterator stats(const FDBToolRequest& request) override;
 
-    ControlIterator control(const FDBToolRequest& request,
-                            ControlAction action,
+    ControlIterator control(const FDBToolRequest& request, ControlAction action,
                             ControlIdentifiers identifiers) override;
 
     MoveIterator move(const FDBToolRequest& request, const eckit::URI& dest) override;
@@ -63,25 +65,26 @@ public: // methods
 
     void flush() override;
 
-protected: // methods
+protected:  // methods
 
-    template <typename VisitorType, typename ... Ts>
-    APIIterator<typename VisitorType::ValueType> queryInternal(const FDBToolRequest& request, Ts ... args);
+    template <typename VisitorType, typename... Ts>
+    APIIterator<typename VisitorType::ValueType> queryInternal(const FDBToolRequest& request, Ts... args);
 
-private: // methods
+private:  // methods
 
     void print(std::ostream& s) const override;
 
-protected: // members
+protected:  // members
 
     std::string home_;
 
     std::unique_ptr<Archiver> archiver_;
+    std::unique_ptr<Reindexer> reindexer_;
     std::unique_ptr<Inspector> inspector_;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
-#endif // fdb5_api_LocalFDB_H
+#endif  // fdb5_api_LocalFDB_H
