@@ -51,7 +51,8 @@ class Schema;
 
 class IndexBase : public eckit::Counted {
 
-public: // methods
+public:  // methods
+
     IndexBase(const Key& key, const std::string& type);
     IndexBase(eckit::Stream& s, const int version);
 
@@ -63,9 +64,9 @@ public: // methods
 
     virtual bool dirty() const = 0;
 
-    virtual void open() = 0;
+    virtual void open()   = 0;
     virtual void reopen() = 0;
-    virtual void close() = 0;
+    virtual void close()  = 0;
 
     /// Flush and Sync data (for mediums where sync() is required)
     virtual void flush() = 0;
@@ -79,8 +80,8 @@ public: // methods
 
     time_t timestamp() const { return timestamp_; }
 
-    virtual bool get(const Key& key, const Key& remapKey, Field &field) const = 0;
-    virtual void put(const Key& key, const Field &field);
+    virtual bool get(const Key& key, const Key& remapKey, Field& field) const = 0;
+    virtual void put(const Key& key, const Field& field);
 
     virtual void encode(eckit::Stream& s, const int version) const;
     virtual void entries(EntryVisitor& visitor) const = 0;
@@ -88,42 +89,45 @@ public: // methods
     /// @note default args on virtual methods is not best practice; no guarantee that overrides will have same defaults
     virtual void dump(std::ostream& out, const char* indent, bool simple = false, bool dumpFields = false) const = 0;
 
-    virtual bool partialMatch(const Rule& rule, const metkit::mars::MarsRequest& request) const;
+    bool partialMatch(const metkit::mars::MarsRequest& indexRequest, const metkit::mars::MarsRequest& datumRequest) const;
     virtual bool mayContain(const Key& key) const;
     virtual bool mayContainPartial(const Key& key) const;
 
     virtual IndexStats statistics() const = 0;
 
-    virtual void print( std::ostream &out ) const = 0;
+    virtual void print(std::ostream& out) const = 0;
 
-    virtual void flock() const = 0;
+    virtual void flock() const   = 0;
     virtual void funlock() const = 0;
 
-protected: // methods
+protected:  // methods
+
     void takeTimestamp() { time(&timestamp_); }
 
-private: // methods
+private:  // methods
+
     void encodeCurrent(eckit::Stream& s, int version) const;
     void encodeLegacy(eckit::Stream& s, int version) const;
 
     void decodeCurrent(eckit::Stream& s, int version);
     void decodeLegacy(eckit::Stream& s, int version);
 
-    virtual void add(const Key& key, const Field &field) = 0;
+    virtual void add(const Key& key, const Field& field) = 0;
 
-protected: // members
+protected:  // members
 
     std::string type_;
 
     /// @note Order of members is important here ...
-    IndexAxis axes_;           ///< This Index spans along these axis
-    Key       key_;            ///< key that selected this index
-    time_t    timestamp_ {0};  ///< timestamp when this Index was flushed
+    IndexAxis axes_;       ///< This Index spans along these axis
+    Key key_;              ///< key that selected this index
+    time_t timestamp_{0};  ///< timestamp when this Index was flushed
 
-    Indexer   indexer_;
+    Indexer indexer_;
 
     friend std::ostream& operator<<(std::ostream& s, const IndexBase& o) {
-        o.print(s); return s;
+        o.print(s);
+        return s;
     }
 };
 
@@ -131,7 +135,7 @@ protected: // members
 
 class Index {
 
-public: // methods
+public:  // methods
 
     Index();
     Index(IndexBase* i);
@@ -169,7 +173,7 @@ public: // methods
 
     void encode(eckit::Stream& s, const int version) const { content_->encode(s, version); }
     void entries(EntryVisitor& v) const { content_->entries(v); }
-    void dump(std::ostream &out, const char* indent, bool simple = false, bool dumpFields = false) const {
+    void dump(std::ostream& out, const char* indent, bool simple = false, bool dumpFields = false) const {
         content_->dump(out, indent, simple, dumpFields);
     }
 
@@ -178,28 +182,30 @@ public: // methods
     IndexBase* content() { return content_; }
     const IndexBase* content() const { return content_; }
 
-    bool partialMatch(const Rule& rule, const metkit::mars::MarsRequest& request) const { return content_->partialMatch(rule, request); }
-    // bool partialMatch(metkit::mars::MarsRequest& request) const { return content_->partialMatch(request); }
+    bool partialMatch(const metkit::mars::MarsRequest& indexRequest, const metkit::mars::MarsRequest& datumRequest) const {
+        return content_->partialMatch(indexRequest, datumRequest);
+    }
     bool mayContain(const Key& key) const { return content_->mayContain(key); }
     bool mayContainPartial(const Key& key) const { return content_->mayContainPartial(key); }
 
     bool null() const { return null_; }
 
-    friend bool operator<  (const Index& i1, const Index& i2) { return i1.content_ <  i2.content_; }
-    friend bool operator== (const Index& i1, const Index& i2) { return i1.content_ == i2.content_; }
+    friend bool operator<(const Index& i1, const Index& i2) { return i1.content_ < i2.content_; }
+    friend bool operator==(const Index& i1, const Index& i2) { return i1.content_ == i2.content_; }
 
     void flock() const { content_->flock(); }
     void funlock() const { content_->funlock(); }
 
-private: // methods
+private:  // methods
 
     void print(std::ostream& s) const { content_->print(s); }
 
     friend std::ostream& operator<<(std::ostream& s, const Index& o) {
-        o.print(s); return s;
+        o.print(s);
+        return s;
     }
 
-private: // members
+private:  // members
 
     IndexBase* content_;
     bool null_;
@@ -207,6 +213,6 @@ private: // members
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
 #endif
