@@ -18,26 +18,25 @@
 #include <memory>
 #include <utility>
 
-#include "eckit/filesystem/PathName.h"
 #include "eckit/filesystem/LocalPathName.h"
+#include "eckit/filesystem/PathName.h"
 #include "eckit/filesystem/URI.h"
 #include "eckit/io/Length.h"
 #include "eckit/io/MemoryHandle.h"
 #include "eckit/log/Timer.h"
 
 #include "fdb5/config/Config.h"
-#include "fdb5/database/DbStats.h"
 #include "fdb5/database/Catalogue.h"
+#include "fdb5/database/DbStats.h"
 #include "fdb5/toc/TocCommon.h"
 #include "fdb5/toc/TocRecord.h"
 #include "fdb5/toc/TocSerialisationVersion.h"
 
 
-
 namespace eckit {
 class Configuration;
 class MemoryHandle;
-}
+}  // namespace eckit
 
 namespace fdb5 {
 
@@ -66,18 +65,17 @@ class TocCopyWatcher : public eckit::TransferWatcher {
         tocCopyStats_.push_back(std::make_pair(now - time_, len));
         time_ = now;
     }
-    
-public:
-    TocCopyWatcher(): idx_(0) {}
 
-    size_t size() const {
-        return tocCopyStats_.size();
-    }
+public:
+
+    TocCopyWatcher() : idx_(0) {}
+
+    size_t size() const { return tocCopyStats_.size(); }
 
     bool next(double& time, eckit::Length& len) {
-        if (tocCopyStats_.size()>idx_) {
+        if (tocCopyStats_.size() > idx_) {
             time = tocCopyStats_[idx_].first;
-            len = tocCopyStats_[idx_].second;
+            len  = tocCopyStats_[idx_].second;
 
             idx_++;
             return true;
@@ -86,28 +84,29 @@ public:
     }
 
 private:
+
     eckit::Timer timer_;
     double time_;
 
     size_t idx_;
     std::vector<std::pair<double, eckit::Length>> tocCopyStats_;
-
 };
 
 //-----------------------------------------------------------------------------
 
 class TocHandler : public TocCommon, private eckit::NonCopyable {
 
-public: // typedefs
+public:  // typedefs
 
     typedef std::vector<TocRecord> TocVec;
-    typedef std::vector< eckit::LocalPathName > TocPaths;
+    typedef std::vector<eckit::LocalPathName> TocPaths;
 
-public: // methods
-    TocHandler( const eckit::PathName &dir, const Config& config);
+public:  // methods
+
+    TocHandler(const eckit::PathName& dir, const Config& config);
 
     /// For initialising sub tocs or diagnostic interrogation.
-    TocHandler(const eckit::PathName& path, const Key& parentKey, eckit::MemoryHandle* cachedToc=nullptr);
+    TocHandler(const eckit::PathName& path, const Key& parentKey, eckit::MemoryHandle* cachedToc = nullptr);
 
     ~TocHandler() override;
 
@@ -115,10 +114,10 @@ public: // methods
     void checkUID() const override;
 
     void writeInitRecord(const Key& tocKey);
-    void writeClearRecord(const Index &);
+    void writeClearRecord(const Index&);
     void writeClearAllRecord();
     void writeSubTocRecord(const TocHandler& subToc);
-    void writeIndexRecord(const Index &);
+    void writeIndexRecord(const Index&);
     void writeSubTocMaskRecord(const TocHandler& subToc);
 
     void reconsolidateIndexesAndTocs();
@@ -128,10 +127,8 @@ public: // methods
 
     /// Return a list of existent indexes. If supplied, also supply a list of associated
     /// subTocs that were read to get these indexes
-    std::vector<Index> loadIndexes(const Catalogue& catalogue,
-                                   bool sorted=false,
-                                   std::set<std::string>* subTocs = nullptr,
-                                   std::vector<bool>* indexInSubtoc = nullptr,
+    std::vector<Index> loadIndexes(const Catalogue& catalogue, bool sorted = false,
+                                   std::set<std::string>* subTocs = nullptr, std::vector<bool>* indexInSubtoc = nullptr,
                                    std::vector<Key>* remapKeys = nullptr) const;
 
     Key databaseKey();
@@ -147,15 +144,14 @@ public: // methods
 
     DbStats stats() const;
 
-    void enumerateMasked(const Catalogue& catalogue,
-                         std::set<std::pair<eckit::URI, eckit::Offset>>& metadata,
+    void enumerateMasked(const Catalogue& catalogue, std::set<std::pair<eckit::URI, eckit::Offset>>& metadata,
                          std::set<eckit::URI>& data) const;
 
     std::vector<eckit::PathName> subTocPaths() const;
     // Utilities for handling locks
     std::vector<eckit::PathName> lockfilePaths() const;
 
-protected: // methods
+protected:  // methods
 
     size_t tocFilesSize() const;
 
@@ -166,19 +162,19 @@ protected: // methods
 
     bool enabled(const ControlIdentifier& controlIdentifier) const;
 
-private: // methods
+private:  // methods
 
     eckit::LocalPathName fullControlFilePath(const std::string& name) const;
     void createControlFile(const std::string& name) const;
     void removeControlFile(const std::string& name) const;
 
-protected: // members
+protected:  // members
 
-    mutable Key parentKey_; // Contains the key of the first TOC explored in subtoc chain
+    mutable Key parentKey_;  // Contains the key of the first TOC explored in subtoc chain
 
     uid_t dbUID() const override;
 
-protected: // methods
+protected:  // methods
 
     // Handle location and remapping information if using a mounted TocCatalogue
     const eckit::LocalPathName& currentDirectory() const;
@@ -194,14 +190,14 @@ protected: // methods
 
     // Given the payload size, returns the record size
 
-    static std::pair<size_t, size_t> recordSizes(TocRecord &r, size_t payloadSize);
+    static std::pair<size_t, size_t> recordSizes(TocRecord& r, size_t payloadSize);
 
     void appendBlock(const void* data, size_t size);
-    void appendBlock(TocRecord &r, size_t payloadSize);
+    void appendBlock(TocRecord& r, size_t payloadSize);
 
     const TocSerialisationVersion& serialisationVersion() const;
 
-private: // methods
+private:  // methods
 
     friend class TocHandlerCloser;
 
@@ -212,7 +208,7 @@ private: // methods
     void close() const;
 
     void appendRaw(const void* data, size_t size);
-    void appendRound(TocRecord &r, size_t payloadSize);
+    void appendRound(TocRecord& r, size_t payloadSize);
 
     /// Populate the masked sub toc list, starting from the _current_position_ in the
     /// file (opened for read). It resets back to the same place when done. This is
@@ -223,19 +219,18 @@ private: // methods
     void populateMaskedEntriesList() const;
     void preloadSubTocs(bool readMasked) const;
 
-    void append(TocRecord &r, size_t payloadSize);
+    void append(TocRecord& r, size_t payloadSize);
 
     // hideSubTocEntries=true returns entries as though only one toc existed (i.e. to hide
     // the mechanism of subtocs).
     // readMasked=true will walk subtocs and read indexes even if they are masked. This is
     // useful for dumping indexes which are cleared, or only referred to in cleared subtocs.
-    bool readNext(TocRecord &r, bool walkSubTocs = true, bool hideSubTocEntries = true,
-                  bool hideClearEntries = true, bool readMasked = false,
-                  const TocRecord** data=nullptr, size_t* length=nullptr) const;
+    bool readNext(TocRecord& r, bool walkSubTocs = true, bool hideSubTocEntries = true, bool hideClearEntries = true,
+                  bool readMasked = false, const TocRecord** data = nullptr, size_t* length = nullptr) const;
 
     void selectSubTocRead(const eckit::LocalPathName& path) const;
 
-    bool readNextInternal(TocRecord &r, const TocRecord** data=nullptr, size_t* length=nullptr) const;
+    bool readNextInternal(TocRecord& r, const TocRecord** data = nullptr, size_t* length = nullptr) const;
 
     std::string userName(long) const;
 
@@ -243,7 +238,7 @@ private: // methods
 
     void dumpTocCache() const;
 
-private: // members
+private:  // members
 
     eckit::LocalPathName tocPath_;
     Config dbConfig_;
@@ -258,14 +253,14 @@ private: // members
     // remapping key?
     Key remapKey_;
 
-    mutable int fd_;      ///< file descriptor, if zero file is not yet open.
+    mutable int fd_;  ///< file descriptor, if zero file is not yet open.
 
     mutable TocCopyWatcher tocReadStats_;
-    mutable std::unique_ptr<eckit::MemoryHandle> cachedToc_; ///< this is only for read path
+    mutable std::unique_ptr<eckit::MemoryHandle> cachedToc_;  ///< this is only for read path
 
     /// The sub toc is initialised in the read or write pathways for maintaining state.
     mutable std::map<eckit::LocalPathName, std::unique_ptr<TocHandler>> subTocReadCache_;
-    mutable TocHandler* subTocRead_; // n.b. non-owning
+    mutable TocHandler* subTocRead_;  // n.b. non-owning
     mutable std::unique_ptr<TocHandler> subTocWrite_;
     mutable size_t count_;
 
@@ -281,6 +276,6 @@ private: // members
 
 //-----------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
-#endif // fdb_TocHandler_H
+#endif  // fdb_TocHandler_H
